# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/notification.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n opus_protobuf/notification.proto\x12\x0cnotification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\":\n\x1eSendValidationCodeEmailRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"O\n\x1cSendTalentOpportunityRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06talent\x18\x02 \x01(\t\x12\x13\n\x0bopportunity\x18\x03 \x01(\t\"$\n\x14SendCsvReportRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"L\n!SendInquireByCulturalAlertRequest\x12\x0f\n\x07\x63ompany\x18\x01 \x01(\t\x12\x16\n\x0e\x63ultural_alert\x18\x02 \x01(\t\"\xab\x01\n\'SendOpportunityEmailNotificationRequest\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07subject\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06\x65mails\x18\x03 \x03(\t\x12\x11\n\x04\x62ody\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04html\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_subjectB\x07\n\x05_bodyB\x07\n\x05_html2\xe6\x04\n\x16NotificationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12\x42\n\x17SendForgotPasswordEmail\x12\x13.common.GetItemByID\x1a\x10.common.Response\"\x00\x12[\n\x17SendValidationCodeEmail\x12,.notification.SendValidationCodeEmailRequest\x1a\x10.common.Response\"\x00\x12W\n\x15SendTalentOpportunity\x12*.notification.SendTalentOpportunityRequest\x1a\x10.common.Response\"\x00\x12G\n\rSendCsvReport\x12\".notification.SendCsvReportRequest\x1a\x10.common.Response\"\x00\x12\x61\n\x1aSendInquireByCulturalAlert\x12/.notification.SendInquireByCulturalAlertRequest\x1a\x10.common.Response\"\x00\x12m\n SendOpportunityEmailNotification\x12\x35.notification.SendOpportunityEmailNotificationRequest\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENDVALIDATIONCODEEMAILREQUEST']._serialized_start=107
  _globals['_SENDVALIDATIONCODEEMAILREQUEST']._serialized_end=165
  _globals['_SENDTALENTOPPORTUNITYREQUEST']._serialized_start=167
  _globals['_SENDTALENTOPPORTUNITYREQUEST']._serialized_end=246
  _globals['_SENDCSVREPORTREQUEST']._serialized_start=248
  _globals['_SENDCSVREPORTREQUEST']._serialized_end=284
  _globals['_SENDINQUIREBYCULTURALALERTREQUEST']._serialized_start=286
  _globals['_SENDINQUIREBYCULTURALALERTREQUEST']._serialized_end=362
  _globals['_SENDOPPORTUNITYEMAILNOTIFICATIONREQUEST']._serialized_start=365
  _globals['_SENDOPPORTUNITYEMAILNOTIFICATIONREQUEST']._serialized_end=536
  _globals['_NOTIFICATIONCONTROLLER']._serialized_start=539
  _globals['_NOTIFICATIONCONTROLLER']._serialized_end=1153
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UploadPictureRequest(_message.Message):
    __slots__ = ("userId", "id", "picture")
    USERID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    userId: str
    id: str
    picture: _common_pb2.Document
    def __init__(self, userId: _Optional[str] = ..., id: _Optional[str] = ..., picture: _Optional[_Union[_common_pb2.Document, _Mapping]] = ...) -> None: ...

class DataRequest(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...

class AccessInstagram(_message.Message):
    __slots__ = ("ids", "id", "user", "url", "access_token")
    IDS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    id: str
    user: str
    url: str
    access_token: str
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., id: _Optional[str] = ..., user: _Optional[str] = ..., url: _Optional[str] = ..., access_token: _Optional[str] = ...) -> None: ...

class InstagramControllerResponse(_message.Message):
    __slots__ = ("data", "have_mean")
    DATA_FIELD_NUMBER: _ClassVar[int]
    HAVE_MEAN_FIELD_NUMBER: _ClassVar[int]
    data: InstagramApiResponse
    have_mean: bool
    def __init__(self, data: _Optional[_Union[InstagramApiResponse, _Mapping]] = ..., have_mean: bool = ...) -> None: ...

class InstagramApiResponse(_message.Message):
    __slots__ = ("value", "metadata", "end_time")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    value: int
    metadata: str
    end_time: str
    def __init__(self, value: _Optional[int] = ..., metadata: _Optional[str] = ..., end_time: _Optional[str] = ...) -> None: ...

class GetInstagramLikesRequest(_message.Message):
    __slots__ = ("data", "broke")
    DATA_FIELD_NUMBER: _ClassVar[int]
    BROKE_FIELD_NUMBER: _ClassVar[int]
    data: AccessInstagram
    broke: bool
    def __init__(self, data: _Optional[_Union[AccessInstagram, _Mapping]] = ..., broke: bool = ...) -> None: ...

class CalculateMeanRequest(_message.Message):
    __slots__ = ("mean", "new_sample", "n")
    MEAN_FIELD_NUMBER: _ClassVar[int]
    NEW_SAMPLE_FIELD_NUMBER: _ClassVar[int]
    N_FIELD_NUMBER: _ClassVar[int]
    mean: int
    new_sample: int
    n: int
    def __init__(self, mean: _Optional[int] = ..., new_sample: _Optional[int] = ..., n: _Optional[int] = ...) -> None: ...

class LinkTensorSocialRequest(_message.Message):
    __slots__ = ("username", "email", "first_name", "last_name", "tenant", "industry", "industry_segment", "country", "birthday", "city")
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_SEGMENT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    username: str
    email: str
    first_name: str
    last_name: str
    tenant: str
    industry: str
    industry_segment: str
    country: str
    birthday: str
    city: str
    def __init__(self, username: _Optional[str] = ..., email: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., tenant: _Optional[str] = ..., industry: _Optional[str] = ..., industry_segment: _Optional[str] = ..., country: _Optional[str] = ..., birthday: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...

class TalentProfile(_message.Message):
    __slots__ = ("user", "country", "tenant", "industry", "birthday", "industry_segment", "gender")
    USER_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_SEGMENT_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    user: str
    country: str
    tenant: str
    industry: str
    birthday: str
    industry_segment: str
    gender: str
    def __init__(self, user: _Optional[str] = ..., country: _Optional[str] = ..., tenant: _Optional[str] = ..., industry: _Optional[str] = ..., birthday: _Optional[str] = ..., industry_segment: _Optional[str] = ..., gender: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import statistic_pb2 as opus__protobuf_dot_statistic__pb2


class StatisticControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/statistic.StatisticController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.uploadSkuPicture = channel.unary_unary(
                '/statistic.StatisticController/uploadSkuPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UserConnectAyrshare = channel.unary_unary(
                '/statistic.StatisticController/UserConnectAyrshare',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetInstagramInfo = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramInfo',
                request_serializer=opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetInstagramFollowers = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramFollowers',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramFollows = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramFollows',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceGender = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceGender',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceCity = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceCity',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceCountry = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceCountry',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramReach = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramReach',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramInteractions = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramInteractions',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramLikes = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramLikes',
                request_serializer=opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramEngagementRate = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramEngagementRate',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.UpdateSocialNetwork = channel.unary_unary(
                '/statistic.StatisticController/UpdateSocialNetwork',
                request_serializer=opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.CreateAudienceInstagram = channel.unary_unary(
                '/statistic.StatisticController/CreateAudienceInstagram',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.CalculateMean = channel.unary_unary(
                '/statistic.StatisticController/CalculateMean',
                request_serializer=opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadBrandPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadBrandPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadOpportunityImage = channel.unary_unary(
                '/statistic.StatisticController/UploadOpportunityImage',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadOpportunityTreatment = channel.unary_unary(
                '/statistic.StatisticController/UploadOpportunityTreatment',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadInterestPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadInterestPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.LinkTikTok = channel.unary_unary(
                '/statistic.StatisticController/LinkTikTok',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.LinkTensorSocial = channel.unary_unary(
                '/statistic.StatisticController/LinkTensorSocial',
                request_serializer=opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.ReadCsvUser = channel.unary_unary(
                '/statistic.StatisticController/ReadCsvUser',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCoverListPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadCoverListPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.TalentUpdateOne = channel.unary_unary(
                '/statistic.StatisticController/TalentUpdateOne',
                request_serializer=opus__protobuf_dot_statistic__pb2.TalentProfile.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.ResyncAllUsers = channel.unary_unary(
                '/statistic.StatisticController/ResyncAllUsers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class StatisticControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def uploadSkuPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserConnectAyrshare(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramFollowers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramFollows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceGender(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceCity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceCountry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramReach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramInteractions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramLikes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramEngagementRate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSocialNetwork(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAudienceInstagram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalculateMean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadBrandPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadOpportunityImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadOpportunityTreatment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadInterestPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkTikTok(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkTensorSocial(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadCsvUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCoverListPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TalentUpdateOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResyncAllUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StatisticControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'uploadSkuPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.uploadSkuPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UserConnectAyrshare': grpc.unary_unary_rpc_method_handler(
                    servicer.UserConnectAyrshare,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetInstagramInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramInfo,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.DataRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetInstagramFollowers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramFollowers,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramFollows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramFollows,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceGender': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceGender,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceCity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceCity,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceCountry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceCountry,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramReach': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramReach,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramInteractions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramInteractions,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramLikes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramLikes,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramEngagementRate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramEngagementRate,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'UpdateSocialNetwork': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSocialNetwork,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.DataRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'CreateAudienceInstagram': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAudienceInstagram,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'CalculateMean': grpc.unary_unary_rpc_method_handler(
                    servicer.CalculateMean,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadBrandPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadBrandPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadOpportunityImage': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadOpportunityImage,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadOpportunityTreatment': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadOpportunityTreatment,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadInterestPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadInterestPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'LinkTikTok': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkTikTok,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'LinkTensorSocial': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkTensorSocial,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'ReadCsvUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadCsvUser,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCoverListPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCoverListPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'TalentUpdateOne': grpc.unary_unary_rpc_method_handler(
                    servicer.TalentUpdateOne,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.TalentProfile.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'ResyncAllUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ResyncAllUsers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'statistic.StatisticController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StatisticController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def uploadSkuPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/uploadSkuPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserConnectAyrshare(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UserConnectAyrshare',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramInfo',
            opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramFollowers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramFollowers',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramFollows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramFollows',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceGender(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceGender',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceCity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceCity',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceCountry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceCountry',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramReach(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramReach',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramInteractions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramInteractions',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramLikes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramLikes',
            opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramEngagementRate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramEngagementRate',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSocialNetwork(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UpdateSocialNetwork',
            opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAudienceInstagram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/CreateAudienceInstagram',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalculateMean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/CalculateMean',
            opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadBrandPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadBrandPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadOpportunityImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadOpportunityImage',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadOpportunityTreatment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadOpportunityTreatment',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadInterestPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadInterestPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkTikTok(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/LinkTikTok',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkTensorSocial(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/LinkTensorSocial',
            opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadCsvUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/ReadCsvUser',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCoverListPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadCoverListPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TalentUpdateOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/TalentUpdateOne',
            opus__protobuf_dot_statistic__pb2.TalentProfile.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResyncAllUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/ResyncAllUsers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SendValidationCodeEmailRequest(_message.Message):
    __slots__ = ("id", "code")
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    id: str
    code: str
    def __init__(self, id: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class SendTalentOpportunityRequest(_message.Message):
    __slots__ = ("id", "talent", "opportunity")
    ID_FIELD_NUMBER: _ClassVar[int]
    TALENT_FIELD_NUMBER: _ClassVar[int]
    OPPORTUNITY_FIELD_NUMBER: _ClassVar[int]
    id: str
    talent: str
    opportunity: str
    def __init__(self, id: _Optional[str] = ..., talent: _Optional[str] = ..., opportunity: _Optional[str] = ...) -> None: ...

class SendCsvReportRequest(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...

class SendInquireByCulturalAlertRequest(_message.Message):
    __slots__ = ("company", "cultural_alert")
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    CULTURAL_ALERT_FIELD_NUMBER: _ClassVar[int]
    company: str
    cultural_alert: str
    def __init__(self, company: _Optional[str] = ..., cultural_alert: _Optional[str] = ...) -> None: ...

class SendOpportunityEmailNotificationRequest(_message.Message):
    __slots__ = ("id", "subject", "emails", "body", "html")
    ID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    EMAILS_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    HTML_FIELD_NUMBER: _ClassVar[int]
    id: str
    subject: str
    emails: _containers.RepeatedScalarFieldContainer[str]
    body: str
    html: str
    def __init__(self, id: _Optional[str] = ..., subject: _Optional[str] = ..., emails: _Optional[_Iterable[str]] = ..., body: _Optional[str] = ..., html: _Optional[str] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CreateStripeCustomerRequest(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import notification_pb2 as opus__protobuf_dot_notification__pb2


class NotificationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/notification.NotificationController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.SendForgotPasswordEmail = channel.unary_unary(
                '/notification.NotificationController/SendForgotPasswordEmail',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendValidationCodeEmail = channel.unary_unary(
                '/notification.NotificationController/SendValidationCodeEmail',
                request_serializer=opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendTalentOpportunity = channel.unary_unary(
                '/notification.NotificationController/SendTalentOpportunity',
                request_serializer=opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendCsvReport = channel.unary_unary(
                '/notification.NotificationController/SendCsvReport',
                request_serializer=opus__protobuf_dot_notification__pb2.SendCsvReportRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendInquireByCulturalAlert = channel.unary_unary(
                '/notification.NotificationController/SendInquireByCulturalAlert',
                request_serializer=opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendOpportunityEmailNotification = channel.unary_unary(
                '/notification.NotificationController/SendOpportunityEmailNotification',
                request_serializer=opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class NotificationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendForgotPasswordEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendValidationCodeEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendTalentOpportunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCsvReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendInquireByCulturalAlert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendOpportunityEmailNotification(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'SendForgotPasswordEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendForgotPasswordEmail,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendValidationCodeEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendValidationCodeEmail,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendTalentOpportunity': grpc.unary_unary_rpc_method_handler(
                    servicer.SendTalentOpportunity,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendCsvReport': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCsvReport,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendCsvReportRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendInquireByCulturalAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.SendInquireByCulturalAlert,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendOpportunityEmailNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendOpportunityEmailNotification,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'notification.NotificationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotificationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendForgotPasswordEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendForgotPasswordEmail',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendValidationCodeEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendValidationCodeEmail',
            opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendTalentOpportunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendTalentOpportunity',
            opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendCsvReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendCsvReport',
            opus__protobuf_dot_notification__pb2.SendCsvReportRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendInquireByCulturalAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendInquireByCulturalAlert',
            opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendOpportunityEmailNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendOpportunityEmailNotification',
            opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/statistic.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dopus_protobuf/statistic.proto\x12\tstatistic\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"e\n\x14UploadPictureRequest\x12\x13\n\x06userId\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\n\n\x02id\x18\x02 \x01(\t\x12!\n\x07picture\x18\x03 \x01(\x0b\x32\x10.common.DocumentB\t\n\x07_userId\"\x1b\n\x0b\x44\x61taRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x82\x01\n\x0f\x41\x63\x63\x65ssInstagram\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0f\n\x02id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x05 \x01(\tB\x05\n\x03_idB\x07\n\x05_userB\x06\n\x04_url\"_\n\x1bInstagramControllerResponse\x12-\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1f.statistic.InstagramApiResponse\x12\x11\n\thave_mean\x18\x02 \x01(\x08\"[\n\x14InstagramApiResponse\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x15\n\x08\x65nd_time\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_end_time\"b\n\x18GetInstagramLikesRequest\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1a.statistic.AccessInstagram\x12\x12\n\x05\x62roke\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_broke\"C\n\x14\x43\x61lculateMeanRequest\x12\x0c\n\x04mean\x18\x01 \x01(\x05\x12\x12\n\nnew_sample\x18\x02 \x01(\x05\x12\t\n\x01n\x18\x03 \x01(\x05\"\xce\x01\n\x17LinkTensorSocialRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x0e\n\x06tenant\x18\x05 \x01(\t\x12\x10\n\x08industry\x18\x06 \x01(\t\x12\x18\n\x10industry_segment\x18\x07 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x08 \x01(\t\x12\x10\n\x08\x62irthday\x18\t \x01(\t\x12\x0c\n\x04\x63ity\x18\n \x01(\t\"\x8c\x01\n\rTalentProfile\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0e\n\x06tenant\x18\x03 \x01(\t\x12\x10\n\x08industry\x18\x04 \x01(\t\x12\x10\n\x08\x62irthday\x18\x05 \x01(\t\x12\x18\n\x10industry_segment\x18\x06 \x01(\t\x12\x0e\n\x06gender\x18\x07 \x01(\t2\x9f\x10\n\x13StatisticController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12G\n\x10uploadSkuPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12>\n\x13UserConnectAyrshare\x12\x13.common.GetItemByID\x1a\x10.common.Response\"\x00\x12>\n\x10GetInstagramInfo\x12\x16.statistic.DataRequest\x1a\x10.common.Response\"\x00\x12]\n\x15GetInstagramFollowers\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12[\n\x13GetInstagramFollows\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x1aGetInstagramAudienceGender\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12`\n\x18GetInstagramAudienceCity\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x63\n\x1bGetInstagramAudienceCountry\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12Y\n\x11GetInstagramReach\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12`\n\x18GetInstagramInteractions\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x11GetInstagramLikes\x12#.statistic.GetInstagramLikesRequest\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x1aGetInstagramEngagementRate\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x41\n\x13UpdateSocialNetwork\x12\x16.statistic.DataRequest\x1a\x10.common.Response\"\x00\x12I\n\x17\x43reateAudienceInstagram\x12\x1a.statistic.AccessInstagram\x1a\x10.common.Response\"\x00\x12\x44\n\rCalculateMean\x12\x1f.statistic.CalculateMeanRequest\x1a\x10.common.Response\"\x00\x12I\n\x12UploadBrandPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12M\n\x16UploadOpportunityImage\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12Q\n\x1aUploadOpportunityTreatment\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12L\n\x15UploadInterestPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12<\n\nLinkTikTok\x12\x1a.statistic.AccessInstagram\x1a\x10.common.Response\"\x00\x12J\n\x10LinkTensorSocial\x12\".statistic.LinkTensorSocialRequest\x1a\x10.common.Response\"\x00\x12\x33\n\x0bReadCsvUser\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12M\n\x16UploadCoverListPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12?\n\x0fTalentUpdateOne\x12\x18.statistic.TalentProfile\x1a\x10.common.Response\"\x00\x12<\n\x0eResyncAllUsers\x12\x16.google.protobuf.Empty\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.statistic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UPLOADPICTUREREQUEST']._serialized_start=101
  _globals['_UPLOADPICTUREREQUEST']._serialized_end=202
  _globals['_DATAREQUEST']._serialized_start=204
  _globals['_DATAREQUEST']._serialized_end=231
  _globals['_ACCESSINSTAGRAM']._serialized_start=234
  _globals['_ACCESSINSTAGRAM']._serialized_end=364
  _globals['_INSTAGRAMCONTROLLERRESPONSE']._serialized_start=366
  _globals['_INSTAGRAMCONTROLLERRESPONSE']._serialized_end=461
  _globals['_INSTAGRAMAPIRESPONSE']._serialized_start=463
  _globals['_INSTAGRAMAPIRESPONSE']._serialized_end=554
  _globals['_GETINSTAGRAMLIKESREQUEST']._serialized_start=556
  _globals['_GETINSTAGRAMLIKESREQUEST']._serialized_end=654
  _globals['_CALCULATEMEANREQUEST']._serialized_start=656
  _globals['_CALCULATEMEANREQUEST']._serialized_end=723
  _globals['_LINKTENSORSOCIALREQUEST']._serialized_start=726
  _globals['_LINKTENSORSOCIALREQUEST']._serialized_end=932
  _globals['_TALENTPROFILE']._serialized_start=935
  _globals['_TALENTPROFILE']._serialized_end=1075
  _globals['_STATISTICCONTROLLER']._serialized_start=1078
  _globals['_STATISTICCONTROLLER']._serialized_end=3157
# @@protoc_insertion_point(module_scope)
